@@ -1,8 +1,6 @@
 import time
 from filecmp import cmp
 
-from metadata_driver_aws.data_plugin import Plugin
-
 
 def test_complete(aws_plugin, test_file_path):
     # Create folder, upload file, list files, download file, delete file
@@ -24,6 +22,13 @@ def test_complete(aws_plugin, test_file_path):
     assert len(files) == 1
     assert files[0] == "test/TEST.md"
 
+    f = open(test_file_path, "rb")
+    test_file_content = f.read()
+    aws_plugin.upload_bytes(test_file_content, f"s3://{bucket_name}/test/TEST_2.md")
+    files = aws_plugin.list(f"s3://{bucket_name}/test/")
+    assert len(files) == 2
+    assert files[1] == "test/TEST_2.md"
+
     # Get presigned_url
     sign_url = aws_plugin.generate_url(f"s3://{bucket_name}/test/TEST.md")
     assert sign_url.startswith(f"http://localhost:9000/{bucket_name}/test/TEST.md")
@@ -34,8 +39,13 @@ def test_complete(aws_plugin, test_file_path):
     )
     assert cmp(test_file_path, "/tmp/test_driver_aws_data_plugin")
 
+    # Download a file
+    file_content = aws_plugin.download_bytes(f"s3://{bucket_name}/test/TEST.md")
+    assert len(test_file_content) == len(file_content)
+
     # Delete the file
     aws_plugin.delete(f"s3://{bucket_name}/test/TEST.md")
+    aws_plugin.delete(f"s3://{bucket_name}/test/TEST_2.md")
     files = aws_plugin.list(f"s3://{bucket_name}/test/")
     assert len(files) == 0
 
